@@ -44,7 +44,8 @@ module TimelogHelper
 
   def user_collection_for_select_options(time_entry)
     collection = time_entry.assignable_users
-    principals_options_for_select(collection, time_entry.user_id)
+    collection << time_entry.user unless time_entry.user.nil? && !collection.include?(time_entry.user)
+    principals_options_for_select(collection, time_entry.user_id.to_s)
   end
 
   def select_hours(data, criteria, value)
@@ -68,7 +69,15 @@ module TimelogHelper
       "[#{l(:label_none)}]"
     elsif k = criteria_options[:klass]
       obj = k.find_by_id(value.to_i)
-      format_object(obj, html)
+      if obj.is_a?(Issue)
+        if obj.visible?
+          html ? link_to_issue(obj) : "#{obj.tracker} ##{obj.id}: #{obj.subject}"
+        else
+          "##{obj.id}"
+        end
+      else
+        format_object(obj, html)
+      end
     elsif cf = criteria_options[:custom_field]
       format_value(value, cf)
     else
