@@ -1,5 +1,7 @@
+# frozen_string_literal: true
+
 # Redmine - project management software
-# Copyright (C) 2006-2017  Jean-Philippe Lang
+# Copyright (C) 2006-2019  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -21,6 +23,10 @@ require 'redmine/field_format'
 class Redmine::NumericFieldFormatTest < ActionView::TestCase
   include ApplicationHelper
 
+  def setup
+    User.current = nil
+  end
+
   def test_integer_field_with_url_pattern_should_format_as_link
     field = IssueCustomField.new(:field_format => 'int', :url_pattern => 'http://foo/%value%')
     custom_value = CustomValue.new(:custom_field => field, :customized => Issue.new, :value => "3")
